@@ -3,11 +3,11 @@ package Alien::FLTK2;
     use strict;
     use warnings;
     use File::Spec::Functions qw[catdir rel2abs canonpath];
-    our $BASE = 0; our $SVN = 7725; our $DEV = -0; our $VERSION = sprintf('%d.%05d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%03d') : ('')), $BASE, $SVN, abs $DEV);
+    our $BASE = 0; our $SVN = 8323; our $DEV = 0; our $VERSION = sprintf('%d.%05d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%03d') : ('')), $BASE, $SVN, abs $DEV);
 
     sub _md5 {
-        return {bz2 => '4d2680a65574e920becf968b899d5311',
-                gz  => '96633dacb732105ef7b3b7853db0373a',
+        return {bz2 => 'd3dc8494c73bc3f0a7f0fed5a7ca0a8e',
+                gz  => 'b735071bf44398e1b8f8c1d9dad7ac30'
         };
     }
     sub _unique_file { return 'src/Widget.cxx' }
@@ -389,7 +389,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2009-2011 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of The Artistic License 2.0. See the F<LICENSE> file included with
@@ -404,6 +404,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 L<Alien::FLTK2|Alien::FLTK2> is based in part on the work of the FLTK project.
 See http://www.fltk.org/.
 
-=for git $Id: FLTK2.pm 0546209 2011-01-10 04:59:34Z sanko@cpan.org $
+=for git $Id: FLTK2.pm 7285db6 2011-02-02 21:25:09Z sanko@cpan.org $
 
 =cut
